@@ -15,21 +15,21 @@ module Serverspec
 
       if @backend_type == 'Ssh'
         print "Vagrant instance y/n: "
-        @vagrant = gets.chomp
+        @vagrant = $stdin.gets.chomp
         if @vagrant =~ (/(true|t|yes|y|1)$/i)
           @vagrant = true
           print "Auto-configure Vagrant from Vagrantfile? y/n: "
-          auto_config = gets.chomp
+          auto_config = $stdin.gets.chomp
           if auto_config =~ (/(true|t|yes|y|1)$/i)
             auto_vagrant_configuration
           else
             print("Input vagrant instance name: ")
-            @hostname = gets.chomp
+            @hostname = $stdin.gets.chomp
           end
         else
           @vagrant = false
           print("Input target host name: ")
-          @hostname = gets.chomp
+          @hostname = $stdin.gets.chomp
         end
       else
         @hostname = 'localhost'
@@ -52,7 +52,7 @@ Select number:
 EOF
 
       print prompt.chop
-      num = gets.to_i - 1
+      num = $stdin.gets.to_i - 1
       puts
 
       @os_type = [ 'UN*X', 'Windows' ][num] || 'UN*X'
@@ -68,7 +68,7 @@ Select a backend type:
 Select number: 
 EOF
       print prompt.chop
-      num = gets.to_i - 1
+      num = $stdin.gets.to_i - 1
       puts
 
       @backend_type = [ 'Ssh', 'Exec' ][num] || 'Exec'
@@ -84,7 +84,7 @@ Select a backend type:
 Select number: 
 EOF
       print prompt.chop
-      num = gets.to_i - 1
+      num = $stdin.gets.to_i - 1
       puts
 
       @backend_type = [ 'WinRM', 'Cmd' ][num] || 'Exec'
@@ -189,7 +189,7 @@ EOF
         list_of_vms = []
         if vagrant_list != ''
           vagrant_list.each_line do |line|
-            if match = /([a-z]+[\s]+)(created|not created|poweroff|running|saved)[\s](\(virtualbox\)|\(vmware\))/.match(line)
+            if match = /([a-z_-]+[\s]+)(created|not created|poweroff|running|saved)[\s](\(virtualbox\)|\(vmware\))/.match(line)
               list_of_vms << match[1].strip!
             end
           end
@@ -198,7 +198,7 @@ EOF
           else
             list_of_vms.each_with_index { |vm, index | puts "#{index}) #{vm}\n" }
             print "Choose a VM from the Vagrantfile: "
-            chosen_vm = gets.chomp
+            chosen_vm = $stdin.gets.chomp
             @hostname = list_of_vms[chosen_vm.to_i]
           end
         else
@@ -214,7 +214,7 @@ EOF
     def self.spec_helper_template
       template = <<-EOF
 require 'serverspec'
-<% if @os_type == 'UN*X' -%>
+<% if @os_type == 'UN*X' && @backend_type == 'Ssh' -%>
 require 'pathname'
 <% end -%>
 <% if @backend_type == 'Ssh' -%>
@@ -224,11 +224,11 @@ require 'net/ssh'
 require 'winrm'
 <% end -%>
 
-include Serverspec::Helper::<%= @backend_type %>
+include SpecInfra::Helper::<%= @backend_type %>
 <% if @os_type == 'UN*X' -%>
-include Serverspec::Helper::DetectOS
+include SpecInfra::Helper::DetectOS
 <% else  -%>
-include Serverspec::Helper::Windows
+include SpecInfra::Helper::Windows
 <% end -%>
 
 <% if @os_type == 'UN*X' -%>
@@ -259,7 +259,7 @@ RSpec.configure do |c|
       if config != ''
         config.each_line do |line|
           if match = /HostName (.*)/.match(line)
-            c.host = match[1]
+            host = match[1]
           elsif  match = /User (.*)/.match(line)
             user = match[1]
           elsif match = /IdentityFile (.*)/.match(line)
@@ -270,7 +270,7 @@ RSpec.configure do |c|
         end
       end
     <%- end -%>
-      c.ssh   = Net::SSH.start(c.host, user, options)
+      c.ssh   = Net::SSH.start(host, user, options)
     end
   end
   <%- end -%>
