@@ -1,6 +1,8 @@
 module Serverspec
   module Type
     class Command < Base
+      attr_accessor :result
+
       def return_stdout?(content)
         ret = backend.run_command(@name)
         if content.instance_of?(Regexp)
@@ -26,6 +28,18 @@ module Serverspec
         ret = backend.run_command(@name)
         ret[:exit_status].to_i == status
       end
+
+      def stdout
+        if @result.nil?
+          @result = backend.run_command(@name)[:stdout]
+        end
+        @result
+      end
+
+      # In ssh access with pty, stderr is merged to stdout
+      # See http://stackoverflow.com/questions/7937651/receiving-extended-data-with-ssh-using-twisted-conch-as-client
+      # So I use stdout instead of stderr
+      alias :stderr :stdout
     end
   end
 end
