@@ -1,8 +1,8 @@
 require 'spec_helper'
 require 'support/powershell_command_runner'
 
-include Serverspec::Helper::WinRM
-include Serverspec::Helper::Windows
+include SpecInfra::Helper::WinRM
+include SpecInfra::Helper::Windows
 
 describe "WinRM" do
   it_behaves_like "a powershell command runner"
