@@ -1,8 +1,6 @@
 require 'spec_helper'
 
-RSpec.configure do |c|
-  c.os = 'Debian'
-end
+include SpecInfra::Helper::Debian
 
 describe group('root') do
   it { should exist }
