@@ -1,8 +1,6 @@
 require 'spec_helper'
 
-RSpec.configure do |c|
-  c.os = 'Gentoo'
-end
+include SpecInfra::Helper::Gentoo
 
 describe command('cat /etc/resolv.conf') do
   let(:stdout) { "nameserver 127.0.0.1\r\n" }
@@ -48,3 +46,22 @@ describe command('cat /etc/resolv.conf') do
   it { should return_exit_status 0 }
   its(:command) { should eq 'cat /etc/resolv.conf' }
 end
+
+describe command('ls -al /') do
+ let(:stdout) { <<EOF
+total 88
+drwxr-xr-x  23 root root  4096 Oct 10 17:19 .
+drwxr-xr-x  23 root root  4096 Oct 10 17:19 ..
+drwxr-xr-x   2 root root  4096 Sep 11 16:43 bin
+drwxr-xr-x   3 root root  4096 Sep 23 18:14 boot
+drwxr-xr-x  14 root root  4260 Oct 14 16:14 dev
+drwxr-xr-x 104 root root  4096 Oct 14 17:34 etc
+drwxr-xr-x   8 root root  4096 Oct  1 15:09 home
+EOF
+    }
+
+  its(:stdout) { should match /bin/ }
+  its(:stderr) { should match /bin/ }
+
+  its(:stdout) { should eq stdout }
+end
