@@ -1,8 +1,6 @@
 require 'spec_helper'
 
-RSpec.configure do |c|
-  c.os = 'Gentoo'
-end
+include SpecInfra::Helper::Gentoo
 
 describe interface('eth0') do
   let(:stdout) { '1000' }
