@@ -1,8 +1,6 @@
 require 'spec_helper'
 
-RSpec.configure do |c|
-  c.os = 'Gentoo'
-end
+include SpecInfra::Helper::Gentoo
 
 describe php_config('default_mimetype') do
   let(:stdout) { 'text/html' }
