@@ -1,8 +1,6 @@
 require 'spec_helper'
 
-RSpec.configure do |c|
-  c.os = 'RedHat'
-end
+include SpecInfra::Helper::RedHat
 
 describe port(80) do
   it { should be_listening }
