@@ -1,8 +1,6 @@
 require 'spec_helper'
 
-RSpec.configure do |c|
-  c.os = 'RedHat'
-end
+include SpecInfra::Helper::RedHat
 
 describe 'Serverspec yumrepo matchers of Red Hat family' do
   describe 'exist' do
