@@ -1,8 +1,6 @@
 require 'spec_helper'
 
-RSpec.configure do |c|
-  c.os = 'Solaris11'
-end
+include SpecInfra::Helper::Solaris11
 
 describe ipfilter do
   it { should have_rule 'pass in quick on lo0 all' }
